List of available font names
------------------------------

The list of available fonts are now easily accessible. Get a list of the
available font names in matplotlib with:

.. code-block:: python

    from matplotlib import font_manager
    font_manager.get_font_names()
